// Copyright (c) 2014 Tais Plougmann Hansen. All rights reserved.
// This Source Code Form is subject to the terms of the BSD 2-Clause license.
// If a copy of the BSD license was not distributed with this file, you can
// obtain one at http://opensource.org/licenses/BSD-2-Clause.

library google_oauth2_jwt.jwt.token;

import 'package:dart_jwt/src/jwt.dart' show JsonWebToken;
import 'package:dart_jwt/src/jwt_claimset.dart' show JwtClaimSet;

/**
 * Decodes JWT received from Google OAuth2 authentication.
 */
JsonWebToken<GoogleClaimSet> decodeGoogleIdToken(String jwt) {
  return new JsonWebToken.decode(jwt, claimSetParser: (Map json) =>
      new GoogleClaimSet.fromJson(json));
}

/**
 * A [JwtClaimSet] for use with Google OAuth2 id tokens.
 */
class GoogleClaimSet extends JwtClaimSet {
  // OpenID Connect claim names.
  final String atHash; // Access Token hash value
  final String azp; // Authorized party - the party to which the ID Token was issued
  final String cHash; // Code hash value
  final String email; // Preferred e-mail address
  final bool emailVerified; // True if the e-mail address has been verified; otherwise false

  // Google-specific claim names.
  final String hd; // Hosted domain

  GoogleClaimSet({String issuer, String subject, DateTime expiry,
      DateTime issuedAt, String audience, String this.atHash, String this.azp,
      String this.cHash, String this.email, bool this.emailVerified,
      String this.hd}) :
        super(issuer, subject, expiry, issuedAt, audience);

  GoogleClaimSet.fromJson(Map json) :
    super.fromJson(json),
    atHash = json['at_hash'],
    azp = json['azp'],
    cHash = json['c_hash'],
    email = json['email'],
    emailVerified = json['email_verified'],
    hd = json['hd'];

  @override
  Map toJson() => super.toJson()..addAll({
    'at_hash': atHash,
    'azp': azp,
    'c_hash': cHash,
    'email': email,
    'email_verified': emailVerified,
    'hd': hd
  });
}
